@@ -801,7 +801,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
 
     def get_card_slug_from_feed(self, feed_slug):
 
-        channel_id = self.get_channel(feed_slug)
+        channel_id = self.get_channel(feed_slug)["id"]
 
         url = self._base_url_ch+"/"+channel_id+"/feed?page=0&limit=100&agentId="+self._agentId
 
