@@ -118,7 +118,7 @@ class Insight_Definition:
 
         url = self.smart_insight_url+"/definitions/"+self.definition_id+"/widgets/"+widget_id
 
-        columns = self.__get_columns(query_ids)
+        columns = self.get_columns(query_ids)
 
         settings = {}
         for field in field_codes.keys():
@@ -155,7 +155,7 @@ class Insight_Definition:
         r = self.__make_put_request(url, body)
         self.components = r.json()["components"]
 
-    def __get_columns(self, query_ids) -> list:
+    def get_columns(self, query_ids) -> list:
 
         url = self.smart_insight_url+"/definitions/"+self.definition_id+"/queries/columns"
         body = {"queryIds": query_ids}
